==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/et_EE.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Süsteemiülene silt „%1$s“ on lisatud süsteemi poolt",
    "Added system tag {systemtag}" : "Lisas süsteemiülese sildi „{systemtag}“",
    "Added system tag %1$s" : "Lisas süsteemiülese sildi „%1$s“",
    "%1$s added system tag %2$s" : "%1$s lisas süsteemiülese sildi „%2$s“",
    "{actor} added system tag {systemtag}" : "{actor} lisas süsteemiülese sildi „{systemtag}“",
    "System tag %1$s removed by the system" : "Süsteemiülene silt „%1$s“ on eemaldatud süsteemi poolt",
    "Removed system tag {systemtag}" : "Eemaldas süsteemiülese sildi „{systemtag}“",
    "Removed system tag %1$s" : "Eemaldas süsteemiülese sildi „%1$s“",
    "%1$s removed system tag %2$s" : "%1$s eemaldas süsteemiülese sildi „%2$s“",
    "{actor} removed system tag {systemtag}" : "{actor} eemaldas süsteemiülese sildi „{systemtag}“",
    "You created system tag %1$s" : "Sa lisasid süsteemiülese sildi „%1$s“",
    "You created system tag {systemtag}" : "Sa lisasid süsteemiülese sildi „{systemtag}“",
    "%1$s created system tag %2$s" : "%1$s lisas süsteemiülese sildi „%2$s“",
    "{actor} created system tag {systemtag}" : "{actor} lisas süsteemiülese sildi „{systemtag}“",
    "You deleted system tag %1$s" : "Sa kustutasid süsteemiülese sildi „%1$s“",
    "You deleted system tag {systemtag}" : "Sa kustutasid süsteemiülese sildi „{systemtag}“",
    "%1$s deleted system tag %2$s" : "%1$s kustutas süsteemiülese sildi „%2$s“",
    "{actor} deleted system tag {systemtag}" : "{actor} kustutas süsteemiülese sildi „{systemtag}“",
    "You updated system tag %2$s to %1$s" : "Sa uuendasid süsteemiülest silti: „%2$s“ => „%1$s“",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sa uuendasid süsteemiülest silti: „{oldsystemtag}“ => „{newsystemtag}“",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uuendas süsteemiülest silti: „%3$s“ => „%2$s“",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uuendas süsteemiülest silti: „{oldsystemtag}“ => „{newsystemtag}“",
    "System tag %2$s was added to %1$s by the system" : "Süsteemiülene silt „%2$s“ on „%1$s“ objektile lisatud süsteemi poolt",
    "System tag {systemtag} was added to {file} by the system" : "Süsteemiülene silt „{systemtag}“ on „{file}“ objektile lisatud süsteemi poolt",
    "You added system tag %2$s to %1$s" : "Sa lisasid süsteemiülese sildi %2$s => %1$s",
    "You added system tag {systemtag} to {file}" : "Sa lisasid süsteemiülese sildi {systemtag} failile {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisas süsteemiülese sildi %3$s => %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisas süsteemiülese sildi {systemtag} failile {file}",
    "System tag %2$s was removed from %1$s by the system" : "Süsteemiülene silt „%2$s“ on „%1$s“ objektilt eemaldatud süsteemi poolt",
    "System tag {systemtag} was removed from {file} by the system" : "Süsteemiülene silt „{systemtag}“ on „{file}“ objektilt eemaldatud süsteemi poolt",
    "You removed system tag %2$s from %1$s" : "Sa eemaldasid süsteemiülese sildi „%2$s“ „%1$s“ objektilt",
    "You removed system tag {systemtag} from {file}" : "Sa eemaldasid süsteemiülese sildi „{systemtag}“ „{file}“ faililt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eemaldas süsteemiülese sildi „%3$s“  „%2$s“ objektilt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eemaldas süsteemiülese sildi „{systemtag}“ „{file}“ faililt",
    "%s (restricted)" : "%s (piiratud)",
    "%s (invisible)" : "%s (nähtamatu)",
    "<strong>System tags</strong> for a file have been modified" : "Selle faili <strong>süsteemiülesed sildid</strong> on muudetud",
    "Files" : "Failid",
    "Tags" : "Sildid",
    "All tagged %s …" : "Kõik sildistatud kui „%s“…",
    "tagged %s" : "sildistatud kui „%s“",
    "Collaborative tags" : "Koostöö sildid",
    "Collaborative tagging functionality which shares tags among people." : "Ühistegevuslik siltide lisamine ja haldus, mis võimaldab jagada silte eri kasutajate vahel.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Ühistegevuslik siltide lisamine ja haldus, mis võimaldab jagada silte eri kasutajate vahel. Sobib hästi tiimidele.\n\n(Kui oled teenusepakkuja, mis ühes serveris majutab mitut organisatsiooni, siis me soovitame, et lülitad selle rakenduse välja - sildid on ju jagatud kõikide kasutajate vahel.)",
    "Public" : "Avalik",
    "Restricted" : "Piiratud",
    "Invisible" : "Nähtamatu",
    "Created tag" : "Silt on loodud",
    "Failed to create tag" : "Sildi loomine ei õnnestunud",
    "Updated tag" : "Silt on uuendatud",
    "Failed to update tag" : "Sildi uuendamine ei õnnestunud",
    "Deleted tag" : "Silt on kustutatud",
    "Failed to delete tag" : "Sildi kustutamine ei õnnestunud",
    "Create or edit tags" : "Loo või muuda silte",
    "Search for a tag to edit" : "Otsi muudetavat silti",
    "Collaborative tags …" : "Ühistegevuslikud sildid…",
    "No tags to select" : "Pole ühtegi silti, mida valida",
    "Tag name" : "Sildi nimi",
    "Tag level" : "Sildi tase",
    "Create" : "Loo",
    "Update" : "Uuenda",
    "Delete" : "Kustuta",
    "Reset" : "Lähtesta",
    "Loading …" : "Laadimine ...",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["„{tag1}“ silt lisatakse 1-le failile ja „{tag2}“ silt eemaldatakse sealt.","„{tag1}“ silt lisatakse {count}-le failile ja „{tag2}“ silt eemaldatakse sealt."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["„{tag}“ silt saab olema lisatud 1-le failile.","„{tag}“ silt saab olema lisatud {count}-le failile."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["„{tag}“ silt saab olema eemaldatud 1-lt faililt.","„{tag}“ silt saab olema eemaldatud {count}-lt faililt."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["„{tags}“ ja „{lastTag}“ sildid saavad olema lisatud 1-le failile.","„{tags}“ ja „{lastTag}“ sildid saavad olema lisatud {count}-le failile."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["„{tags}“ ja „{lastTag}“ sildid saavad olema eemaldatud 1-lt faililt.","„{tags}“ ja „{lastTag}“ sildid saavad olema eemaldatud {count}-lt faililt."],
    "{displayName} (hidden)" : "{displayName} (peidetud)",
    "{displayName} (restricted)" : "{displayName} (piiratud)",
    "Only admins can create new tags" : "Vaid peakasutajad saavad luua uusi silte",
    "Failed to apply tags changes" : "Siltide muudatusi ei õnnestunud salvestada",
    "Manage tags" : "Halda silte",
    "Applying tags changes…" : "Salvestan sildi muudatusi…",
    "Search or create tag" : "Otsi või loo silt",
    "Search tag" : "Otsi silti",
    "Change tag color" : "Muuda sildi värvi",
    "Create new tag" : "Loo uus silt",
    "Cancel" : "Tühista",
    "Apply" : "Rakenda",
    "Failed to load tags" : "Siltide laadimine ei õnnestu",
    "Failed to load selected tags" : "Valitud siltide laadimine ei õnnestu",
    "Failed to select tag" : "Sildi valimine ei õnnestu",
    "System admin disabled tag creation. You can only use existing ones." : "Peakasutaja on keelanud siltide loomise. Sa võid kasutada vaid olemasolevaid.",
    "Loading collaborative tags …" : "Laadin ühistegevuslikke silte…",
    "Search or create collaborative tags" : "Otsi või loo ühistegevuslikke silte",
    "No tags to select, type to create a new tag" : "Pole ühtegi valitavat silti, uue sildi lisamiseks hakka kirjutama",
    "Unable to update setting" : "Seadistuse uuendamine ei õnnestu",
    "System tag creation is now restricted to administrators" : "Vaid peakasutajad saavad nüüd luua süsteemiüleseid silte",
    "System tag creation is now allowed for everybody" : "Kõik saavad nüüd luua süsteemiüleseid silte",
    "System tag management" : "Süsteemiüleste siltide haldus",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Kui see eelistus on sisse lülitatud, siis vaid peakasutajad saavad luua ja muuta süsteemiüleseid silte. Kõik kasutajad saavad neid failidele lisada või sealt eemaldada.",
    "Restrict tag creation and editing to administrators" : "Luba vaid peakasutajatel luua süsteemiüleseid silte",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Ühistegevuslikud sildid on saadaval kõikide kasutajate jaoks. Piiratud sildid on kasutajatele nähtavad, kuid nad ei saa neid silte määrata. Nähtamatud sildid on sisemiseks kasutuseks ja kasutajad neid ei näe ega saa neid määrata.",
    "Assigned collaborative tags" : "Eelkirjeldatud ühistegevuslikud sildid",
    "Open in Files" : "Ava failirakenduses",
    "List of tags and their associated files and folders." : "Siltude ja nendega seotud failide ja kaustade loend.",
    "No tags found" : "Silte ei leidinud",
    "Tags you have created will show up here." : "Sinu loodud sildid saavad olema nähtavad siin.",
    "Failed to load tag" : "Sildi laadimine ei õnnestunud",
    "Failed to load last used tags" : "Viimatikasutatud siltide laadimine ei õnnestunud",
    "Missing \"Content-Location\" header" : "„Content-Location“ päisekirje on puudu",
    "A tag with the same name already exists" : "Sellise nimega silt on juba olemas",
    "Failed to load tags for file" : "Faili silte ei õnnestunud laadida",
    "Failed to set tag for file" : "Failile ei õnnestunud silte lisada",
    "Failed to delete tag for file" : "Faililt ei õnnestunud silte eemaldada",
    "File tags modification canceled" : "Failide siltide muutmine on katkestatud",
    "Select or create tags to apply to all selected files" : "Vali või loo sildid kõikide valitud failide jaoks",
    "Select tags to apply to all selected files" : "Vali sildid kõikide valitud failide jaoks",
    "Apply changes" : "Rakenda muudatused"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/systemtags/l10n/et_EE.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Süsteemiülene silt „%1$s“ on lisatud süsteemi poolt",
    "Added system tag {systemtag}" : "Lisas süsteemiülese sildi „{systemtag}“",
    "Added system tag %1$s" : "Lisas süsteemiülese sildi „%1$s“",
    "%1$s added system tag %2$s" : "%1$s lisas süsteemiülese sildi „%2$s“",
    "{actor} added system tag {systemtag}" : "{actor} lisas süsteemiülese sildi „{systemtag}“",
    "System tag %1$s removed by the system" : "Süsteemiülene silt „%1$s“ on eemaldatud süsteemi poolt",
    "Removed system tag {systemtag}" : "Eemaldas süsteemiülese sildi „{systemtag}“",
    "Removed system tag %1$s" : "Eemaldas süsteemiülese sildi „%1$s“",
    "%1$s removed system tag %2$s" : "%1$s eemaldas süsteemiülese sildi „%2$s“",
    "{actor} removed system tag {systemtag}" : "{actor} eemaldas süsteemiülese sildi „{systemtag}“",
    "You created system tag %1$s" : "Sa lisasid süsteemiülese sildi „%1$s“",
    "You created system tag {systemtag}" : "Sa lisasid süsteemiülese sildi „{systemtag}“",
    "%1$s created system tag %2$s" : "%1$s lisas süsteemiülese sildi „%2$s“",
    "{actor} created system tag {systemtag}" : "{actor} lisas süsteemiülese sildi „{systemtag}“",
    "You deleted system tag %1$s" : "Sa kustutasid süsteemiülese sildi „%1$s“",
    "You deleted system tag {systemtag}" : "Sa kustutasid süsteemiülese sildi „{systemtag}“",
    "%1$s deleted system tag %2$s" : "%1$s kustutas süsteemiülese sildi „%2$s“",
    "{actor} deleted system tag {systemtag}" : "{actor} kustutas süsteemiülese sildi „{systemtag}“",
    "You updated system tag %2$s to %1$s" : "Sa uuendasid süsteemiülest silti: „%2$s“ => „%1$s“",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Sa uuendasid süsteemiülest silti: „{oldsystemtag}“ => „{newsystemtag}“",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uuendas süsteemiülest silti: „%3$s“ => „%2$s“",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uuendas süsteemiülest silti: „{oldsystemtag}“ => „{newsystemtag}“",
    "System tag %2$s was added to %1$s by the system" : "Süsteemiülene silt „%2$s“ on „%1$s“ objektile lisatud süsteemi poolt",
    "System tag {systemtag} was added to {file} by the system" : "Süsteemiülene silt „{systemtag}“ on „{file}“ objektile lisatud süsteemi poolt",
    "You added system tag %2$s to %1$s" : "Sa lisasid süsteemiülese sildi %2$s => %1$s",
    "You added system tag {systemtag} to {file}" : "Sa lisasid süsteemiülese sildi {systemtag} failile {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisas süsteemiülese sildi %3$s => %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisas süsteemiülese sildi {systemtag} failile {file}",
    "System tag %2$s was removed from %1$s by the system" : "Süsteemiülene silt „%2$s“ on „%1$s“ objektilt eemaldatud süsteemi poolt",
    "System tag {systemtag} was removed from {file} by the system" : "Süsteemiülene silt „{systemtag}“ on „{file}“ objektilt eemaldatud süsteemi poolt",
    "You removed system tag %2$s from %1$s" : "Sa eemaldasid süsteemiülese sildi „%2$s“ „%1$s“ objektilt",
    "You removed system tag {systemtag} from {file}" : "Sa eemaldasid süsteemiülese sildi „{systemtag}“ „{file}“ faililt",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eemaldas süsteemiülese sildi „%3$s“  „%2$s“ objektilt",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eemaldas süsteemiülese sildi „{systemtag}“ „{file}“ faililt",
    "%s (restricted)" : "%s (piiratud)",
    "%s (invisible)" : "%s (nähtamatu)",
    "<strong>System tags</strong> for a file have been modified" : "Selle faili <strong>süsteemiülesed sildid</strong> on muudetud",
    "Files" : "Failid",
    "Tags" : "Sildid",
    "All tagged %s …" : "Kõik sildistatud kui „%s“…",
    "tagged %s" : "sildistatud kui „%s“",
    "Collaborative tags" : "Koostöö sildid",
    "Collaborative tagging functionality which shares tags among people." : "Ühistegevuslik siltide lisamine ja haldus, mis võimaldab jagada silte eri kasutajate vahel.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Ühistegevuslik siltide lisamine ja haldus, mis võimaldab jagada silte eri kasutajate vahel. Sobib hästi tiimidele.\n\n(Kui oled teenusepakkuja, mis ühes serveris majutab mitut organisatsiooni, siis me soovitame, et lülitad selle rakenduse välja - sildid on ju jagatud kõikide kasutajate vahel.)",
    "Public" : "Avalik",
    "Restricted" : "Piiratud",
    "Invisible" : "Nähtamatu",
    "Created tag" : "Silt on loodud",
    "Failed to create tag" : "Sildi loomine ei õnnestunud",
    "Updated tag" : "Silt on uuendatud",
    "Failed to update tag" : "Sildi uuendamine ei õnnestunud",
    "Deleted tag" : "Silt on kustutatud",
    "Failed to delete tag" : "Sildi kustutamine ei õnnestunud",
    "Create or edit tags" : "Loo või muuda silte",
    "Search for a tag to edit" : "Otsi muudetavat silti",
    "Collaborative tags …" : "Ühistegevuslikud sildid…",
    "No tags to select" : "Pole ühtegi silti, mida valida",
    "Tag name" : "Sildi nimi",
    "Tag level" : "Sildi tase",
    "Create" : "Loo",
    "Update" : "Uuenda",
    "Delete" : "Kustuta",
    "Reset" : "Lähtesta",
    "Loading …" : "Andmed on laadimisel…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["„{tag1}“ silt lisatakse 1-le failile ja „{tag2}“ silt eemaldatakse sealt.","„{tag1}“ silt lisatakse {count}-le failile ja „{tag2}“ silt eemaldatakse sealt."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["„{tag}“ silt saab olema lisatud 1-le failile.","„{tag}“ silt saab olema lisatud {count}-le failile."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["„{tag}“ silt saab olema eemaldatud 1-lt faililt.","„{tag}“ silt saab olema eemaldatud {count}-lt faililt."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["„{tags}“ ja „{lastTag}“ sildid saavad olema lisatud 1-le failile.","„{tags}“ ja „{lastTag}“ sildid saavad olema lisatud {count}-le failile."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["„{tags}“ ja „{lastTag}“ sildid saavad olema eemaldatud 1-lt faililt.","„{tags}“ ja „{lastTag}“ sildid saavad olema eemaldatud {count}-lt faililt."],
    "{displayName} (hidden)" : "{displayName} (peidetud)",
    "{displayName} (restricted)" : "{displayName} (piiratud)",
    "Only admins can create new tags" : "Vaid peakasutajad saavad luua uusi silte",
    "Failed to apply tags changes" : "Siltide muudatusi ei õnnestunud salvestada",
    "Manage tags" : "Halda silte",
    "Applying tags changes…" : "Salvestan sildi muudatusi…",
    "Search or create tag" : "Otsi või loo silt",
    "Search tag" : "Otsi silti",
    "Change tag color" : "Muuda sildi värvi",
    "Create new tag" : "Loo uus silt",
    "Choose tags for the selected files" : "Määta sildid valitud failidele",
    "Cancel" : "Tühista",
    "Apply" : "Rakenda",
    "Failed to load selected tags" : "Valitud siltide laadimine ei õnnestu",
    "Failed to load tags" : "Siltide laadimine ei õnnestu",
    "Failed to select tag" : "Sildi valimine ei õnnestu",
    "System admin disabled tag creation. You can only use existing ones." : "Peakasutaja on keelanud siltide loomise. Sa võid kasutada vaid olemasolevaid.",
    "Loading collaborative tags …" : "Laadin ühistegevuslikke silte…",
    "Search or create collaborative tags" : "Otsi või loo ühistegevuslikke silte",
    "No tags to select, type to create a new tag" : "Pole ühtegi valitavat silti, uue sildi lisamiseks hakka kirjutama",
    "Unable to update setting" : "Seadistuse uuendamine ei õnnestu",
    "System tag creation is now restricted to administrators" : "Vaid peakasutajad saavad nüüd luua süsteemiüleseid silte",
    "System tag creation is now allowed for everybody" : "Kõik saavad nüüd luua süsteemiüleseid silte",
    "System tag management" : "Süsteemiüleste siltide haldus",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Kui see eelistus on sisse lülitatud, siis vaid peakasutajad saavad luua ja muuta süsteemiüleseid silte. Kõik kasutajad saavad neid failidele lisada või sealt eemaldada.",
    "Restrict tag creation and editing to administrators" : "Luba vaid peakasutajatel luua süsteemiüleseid silte",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Ühistegevuslikud sildid on saadaval kõikide kasutajate jaoks. Piiratud sildid on kasutajatele nähtavad, kuid nad ei saa neid silte määrata. Nähtamatud sildid on sisemiseks kasutuseks ja kasutajad neid ei näe ega saa neid määrata.",
    "Assigned collaborative tags" : "Eelkirjeldatud ühistegevuslikud sildid",
    "Open in Files" : "Ava failirakenduses",
    "List of tags and their associated files and folders." : "Siltude ja nendega seotud failide ja kaustade loend.",
    "No tags found" : "Silte ei leidinud",
    "Tags you have created will show up here." : "Sinu loodud sildid saavad olema nähtavad siin.",
    "Failed to load tag" : "Sildi laadimine ei õnnestunud",
    "Failed to load last used tags" : "Viimatikasutatud siltide laadimine ei õnnestunud",
    "Missing \"Content-Location\" header" : "„Content-Location“ päisekirje on puudu",
    "A tag with the same name already exists" : "Sellise nimega silt on juba olemas",
    "Failed to load tags for file" : "Faili silte ei õnnestunud laadida",
    "Failed to set tag for file" : "Failile ei õnnestunud silte lisada",
    "Failed to delete tag for file" : "Faililt ei õnnestunud silte eemaldada",
    "Collaborative tags …" : "Ühistegevuslikud sildid…",
    "Loading …" : "Laadimine ...",
    "File tags modification canceled" : "Failide siltide muutmine on katkestatud",
    "Select or create tags to apply to all selected files" : "Vali või loo sildid kõikide valitud failide jaoks",
    "Select tags to apply to all selected files" : "Vali sildid kõikide valitud failide jaoks",
    "Apply changes" : "Rakenda muudatused",
    "Loading collaborative tags …" : "Laadin ühistegevuslikke silte…"
},
"nplurals=2; plural=(n != 1);");
